@@ -16,6 +16,8 @@ our %NOT_A_MULT_VALUE = map { $_ => 1 }
 
 use constant _INTERNAL_DEBUG => 0;
 
+our $COMMENT_REGEX = qr/[#;!]/;
+
 ################################################
 sub parse {
 ################################################
@@ -32,7 +34,7 @@ sub parse {
 
     while (@$text) {
         local $_ = shift @$text;
-        s/^\s*#.*//;
+        s/^\s*$COMMENT_REGEX.*//;
         next unless /\S/;
     
         my @parts = ();
@@ -41,7 +43,7 @@ sub parse {
             my $prev = $1;
             my $next = shift(@$text);
             $next =~ s/^ +//g;  #leading spaces
-            $next =~ s/^#.*//;
+            $next =~ s/^$COMMENT_REGEX.*//;
             $_ = $prev. $next;
             chomp;
         }
@@ -136,6 +138,8 @@ sub value {
 
 __END__
 
+=encoding utf8
+
 =head1 NAME
 
 Log::Log4perl::Config::PropertyConfigurator - reads properties file
@@ -184,7 +188,7 @@ Log::Log4perl::Config::LDAPConfigurator (tbd!)
 
 =head1 LICENSE
 
-Copyright 2002-2012 by Mike Schilli E<lt>m@perlmeister.comE<gt> 
+Copyright 2002-2013 by Mike Schilli E<lt>m@perlmeister.comE<gt> 
 and Kevin Goess E<lt>cpan@goess.orgE<gt>.
 
 This library is free software; you can redistribute it and/or modify
@@ -209,7 +213,8 @@ Contributors (in alphabetical order):
 Ateeq Altaf, Cory Bennett, Jens Berthold, Jeremy Bopp, Hutton
 Davidson, Chris R. Donnelly, Matisse Enzer, Hugh Esco, Anthony
 Foiani, James FitzGibbon, Carl Franks, Dennis Gregorovic, Andy
-Grundman, Paul Harrington, David Hull, Robert Jacobson, Jason Kohles, 
-Jeff Macdonald, Markus Peter, Brett Rann, Peter Rabbitson, Erik
-Selberg, Aaron Straup Cope, Lars Thegler, David Viner, Mac Yang.
+Grundman, Paul Harrington, Alexander Hartmaier  David Hull, 
+Robert Jacobson, Jason Kohles, Jeff Macdonald, Markus Peter, 
+Brett Rann, Peter Rabbitson, Erik Selberg, Aaron Straup Cope, 
+Lars Thegler, David Viner, Mac Yang.
 
